"""Constants."""
from __future__ import absolute_import, division, print_function

CONF_FILE = ".bumplus.toml"
